==> sight_21.0.0.orig.tar.gz: sight-21.0.0/libs/geometry/data/test/tu/PointListTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2017-2021 IRCAD France
 * Copyright (C) 2017-2018 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <data/PointList.hpp>

#include <cppunit/extensions/HelperMacros.h>

namespace sight::geometry::data
{

namespace ut
{

class PointListTest : public CPPUNIT_NS::TestFixture
{
private:

    CPPUNIT_TEST_SUITE(PointListTest);
    CPPUNIT_TEST(computeDistance);
    CPPUNIT_TEST(transform);
    CPPUNIT_TEST(associate);
    CPPUNIT_TEST(removeClosestPointNominal);
    CPPUNIT_TEST(removeClosestPointExtreme);
    CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp();
    void tearDown();

    void computeDistance();

    void transform();

    void associate();

    void removeClosestPointNominal();

    void removeClosestPointExtreme();
};

} //namespace ut

} //namespace sight::geometry::data

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/libs/geometry/data/test/tu/PointListTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2017-2022 IRCAD France
 * Copyright (C) 2017-2018 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <data/PointList.hpp>

#include <cppunit/extensions/HelperMacros.h>

namespace sight::geometry::data::ut
{

class PointListTest : public CPPUNIT_NS::TestFixture
{
private:

    CPPUNIT_TEST_SUITE(PointListTest);
    CPPUNIT_TEST(computeDistance);
    CPPUNIT_TEST(transform);
    CPPUNIT_TEST(associate);
    CPPUNIT_TEST(removeClosestPointNominal);
    CPPUNIT_TEST(removeClosestPointExtreme);
    CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp() override;
    void tearDown() override;

    static void computeDistance();

    static void transform();

    static void associate();

    static void removeClosestPointNominal();

    static void removeClosestPointExtreme();
};

} // namespace sight::geometry::data::ut
